/*
 * i18next-node-zanata-backend
 * https://bitbucket.org/tagoh/i18next-node-zanata-backend
 *
 * Copyright (c) 2016 Akira TAGOH
 * Licensedunder the MIT license.
 */
'use strict';

var _ = require('underscore');
var ZanataClient = require('zanata-js').ZanataClient;
var i18nextconv = require('i18next-conv');

var getDefaults = function(args) {
  var ret = _.clone(args);
  ret = _.extend({
    url: 'https://translate.zanata.org'
  }, ret);

  return ret;
};

var Backend = function(services, options) {
  if (!(this instanceof Backend)) {
    throw new TypeError('Unable to call a class as a function');
  }
  this.init(services, options);
};

Backend.prototype.init = function(services, options, i18nextOptions) {
  this.services = services;
  this.options = getDefaults(options);
};

Backend.prototype.read = function(lang, ns, cb) {
  var p = new ZanataClient.Project(this.options)
    .on('fail', function(e) {
      cb(e, false);
    })
    .on('data', function(d) {
      var f = function(result) {
        cb(null, JSON.parse(result));
      };
      i18nextconv.gettextToI18next(lang, d.data)
        .then(f);
    })
    .on('end', function(r) {
    });
  if (lang !== 'en')
    p.pullTranslation(null, null, ns, lang,
                      {verbose: this.options.verbose,
                       potdir: this.options.cachedir,
                       podir: this.options.cachedir});
  else
    cb(false, false);
};

Backend.prototype.readMulti = function(lang, ns, cb) {
  console.log('readMulti');
};

Backend.prototype.create = function(lang, ns, key, val) {
  console.log('create');
};

Backend.type = 'backend';

module.exports = Backend;
